/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;

import org.ow2.petals.kernel.ws.api.to.AttachmentDescriptor;

/**
 * Access to the artifact repository service.
 * @author Christophe HAMERLING - EBM WebSourcing
 */
@WebService(name = "ArtifactRepositoryService")
public interface ArtifactRepositoryService {

    /**
     * Upload the artifact to the PEtALS container. This will add the artifact
     * to the repository service depending on its type (component, service
     * assembly, shared library)
     *
     * @param attachmentDescriptor
     * @return
     */
    @WebMethod
    boolean addArtifact(@WebParam(name = "attachment") AttachmentDescriptor attachmentDescriptor)
            throws PEtALSWebServiceException;

    /**
     * Get all the components which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "component")
    String[] getComponents();

    /**
     * Get all the service assemblies which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "sa")
    String[] getServiceAssemblies();

    /**
     * Get all the shared libraries which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "sl")
    String[] getSharedLibraries();

}
