/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api.to;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;

import org.ow2.petals.kernel.ws.api.Constants;

/**
 * @author Charles Casadei - EBM WebSourcing
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(namespace = Constants.NS, name = "subdomain-information")
public class SubdomainInformation {

    @XmlEnum
    public enum SubdomainMode {
        MASTERSLAVE, FLOODING, STANDALONE
    };

    @XmlElement(name="subdomain-name", required=true, nillable=false)
    private String name;

    @XmlElement(name="subdomain-mode", required=true, nillable=false)
    private SubdomainMode subdomainMode;

    @XmlElement(name="description", required=false, nillable=true)
    private String description;

    @XmlElement(name="network-time-synchronized", required=false, nillable=true)
    private boolean networkTimeSynchronized;

    @XmlElement(name="containers", required=false, nillable=true)
    private List<ContainerInformation> containers;

    public SubdomainInformation() {

    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public SubdomainMode getSubdomainMode() {
        return subdomainMode;
    }

    public void setSubdomainMode(SubdomainMode subdomainMode) {
        this.subdomainMode = subdomainMode;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public boolean isNetworkTimeSynchronized() {
        return networkTimeSynchronized;
    }

    public void setNetworkTimeSynchronized(boolean networkTimeSynchronized) {
        this.networkTimeSynchronized = networkTimeSynchronized;
    }

    public List<ContainerInformation> getContainers() {
        return containers;
    }

    public void setContainers(List<ContainerInformation> containers) {
        this.containers = containers;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }

        final SubdomainInformation other = (SubdomainInformation) obj;
        if ((this.name == null) ? (other.name != null) : !this.name.equals(other.name)) {
            return false;
        }

        if (this.subdomainMode != other.subdomainMode) {
            return false;
        }

        if ((this.description == null) ? (other.description != null) : !this.description.equals(other.description)) {
            return false;
        }

        if (this.networkTimeSynchronized != other.networkTimeSynchronized) {
            return false;
        }

        if ((this.containers != null) && (other.containers != null)) {
            if (this.containers.size() != other.containers.size()) {
                return false;
            }

            for (ContainerInformation container : this.containers) {
                if (! other.containers.contains(container)) {
                    return false;
                }
            }
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 97 * hash + (this.name != null ? this.name.hashCode() : 0);
        hash = 97 * hash + this.subdomainMode.hashCode();
        hash = 97 * hash + (this.description != null ? this.description.hashCode() : 0);
        hash = 97 * hash + (this.networkTimeSynchronized ? 1 : 0);
        hash = 97 * hash + (this.containers != null ? this.containers.size() : 0);
        return hash;
    }

    @Override
    public String toString() {
        StringBuilder toStringBuilder = new StringBuilder();
        toStringBuilder.append("SubdomainInformation [");
        toStringBuilder.append("subdomain-name=").append(this.name).append(", ");
        toStringBuilder.append("subdomain-mode=").append(this.subdomainMode).append(", ");
        toStringBuilder.append("description=").append(this.description).append(", ");
        toStringBuilder.append("network-time-synchronized=").append(this.networkTimeSynchronized).append(", ");
        toStringBuilder.append("containers={");

        if (this.containers != null) {
            for (ContainerInformation container : this.containers) {
                toStringBuilder.append(container).append(", ");
            }
        }

        toStringBuilder.append("}]");

        return toStringBuilder.toString();
    }
}
